
This documentation is generated using the Sphinx documentation generator. The source files for the documentation are
located in the *doc/* directory of the Pymilvus distribution. To generate the docs locally run the following command
under directory *doc/*:

```shell
$ make html
```

The documentation should be generated under directory *build/html*.

To preview it, you can open *index.html* in your browser.

Or run a web server in that directory:

```shell
$ python3 -m http.server
```

Then open your browser to <http://localhost:8000>.
